@@ -11,7 +11,6 @@ from typing import Callable, Optional
 from uuid import uuid4
 
 from .const import (
-    COMMAND_OPTIONS,
     COMMAND_PAUSE,
     COMMAND_POWER,
     COMMAND_REQUEST_WORKSERVER_ASSIGNMENT,
@@ -174,9 +173,7 @@ class FoldingAtHomeController:
 
     async def set_power_level_async(self, power_level: PowerLevel) -> None:
         """Set the power level."""
-        await self._send_command_async(
-            f"{COMMAND_OPTIONS} {COMMAND_POWER} {power_level.value}"
-        )
+        await self._send_command_async(f"{COMMAND_POWER} {power_level.value}")
 
     async def pause_slot_async(self, slot_id: str) -> None:
         """Pause a slot."""
@@ -201,6 +198,7 @@ class FoldingAtHomeController:
     async def _try_parse_pyon_message_async(self) -> None:
         """Read from the socket until a full message has been received."""
         raw_message = await self._serialconnection.read_async()
+        _LOGGER.debug("Received message: %s", raw_message)
         if PY_ON_MESSAGE_HEADER in raw_message:
             raw_messages = []
             message_type = get_message_type_from_message(raw_message)
